@@ -201,7 +201,9 @@ class Spreadsheet:
             fields="lastModifyingUser,modifiedTime",
             supportsAllDrives=True
         ).execute()
-        return r["modifiedTime"], r["lastModifyingUser"].get("emailAddress")
+        if r.get("lastModifyingUser"):
+            return r["modifiedTime"], r["lastModifyingUser"].get("emailAddress")
+        return r["modifiedTime"], None
 
     def get_info_from_worksheet(self, key, **kwargs):
         jinja_env = jinja2.Environment()
